@@ -67,4 +67,14 @@ void PlasmaTube::setApplicationProxy()
     QNetworkProxy::setApplicationProxy(proxy);
 }
 
+void PlasmaTube::saveCurrentSource()
+{
+    auto stateConfig = KSharedConfig::openStateConfig();
+    auto generalGroup = stateConfig->group(QStringLiteral("General"));
+
+    generalGroup.writeEntry(QStringLiteral("LastSource"), m_sourceManager->selectedSource()->uuid());
+
+    stateConfig->sync();
+}
+
 #include "moc_plasmatube.cpp"
\ No newline at end of file
