@@ -25,6 +25,16 @@ MpvObject::MpvObject(QQuickItem *parent)
     observeProperty(QStringLiteral("pause"), MPV_FORMAT_FLAG);
 
     connect(mpvController(), &MpvController::propertyChanged, this, &MpvObject::onPropertyChanged, Qt::QueuedConnection);
+    connect(mpvController(), &MpvController::fileLoaded, this, [=]() {
+        // Note that audio-add only works in a specific time, the best is right after the file is loaded.
+        // For more details on this issue, see https://github.com/flaviotordini/minitube/issues/155.
+        Q_EMIT command(QStringList() << QStringLiteral("audio-add") << m_audioUrl << QStringLiteral("select"));
+    });
+}
+
+void MpvObject::setAudioUrl(const QString &audioUrl)
+{
+    m_audioUrl = audioUrl;
 }
 
 qreal MpvObject::position() const
